@@ -70,7 +70,7 @@ class Coupling(AbstractEffect):
         # The coupling coefficient -------------------------------------
         self._op: np.ndarray = np.array([])
         self._kappa_op: np.ndarray = np.array([])
-        self._kappa: Union[np.ndarray, Callable]
+        self._kappa: Callable
         if (callable(kappa)):
             self._kappa = kappa
         else:
@@ -79,6 +79,11 @@ class Coupling(AbstractEffect):
             self._order_taylor = len(kappa_) - 1
     # ==================================================================
     @property
+    def kappa(self) -> Callable:
+
+        return self._kappa            
+    # ==================================================================
+    @property
     def order_taylor(self) -> int:
 
         return self._order_taylor
