@@ -1,17 +1,16 @@
-# This This file is part of Optcom.
+# Copyright 2019 The Optcom Authors
 #
-# Optcom is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-# Optcom is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
-# You should have received a copy of the GNU General Public License
-# along with Optcom.  If not, see <https://www.gnu.org/licenses/>.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 """.. moduleauthor:: Sacha Medaer"""
 
@@ -232,7 +231,21 @@ class Layout(object):
 
             raise DelError(error_msg + str(port_1) + str(port_2))
     # ==================================================================
-    def link(self, *links: Tuple[Port, Port]) -> None:
+    def add_link(self, port_1: Port, port_2: Port) -> None:
+        """Add one bidirectionnal edge in the Layout.
+
+        Parameters
+        ----------
+        port_1 :
+            First port to be linked.
+        port_2 :
+            Second port to be linked.
+
+        """
+
+        self._add_edge(port_1, port_2, False)
+    # ==================================================================
+    def add_links(self, *links: Tuple[Port, Port]) -> None:
         """Add a series of bidirectionnal edges in the Layout.
 
         Parameters
@@ -245,7 +258,20 @@ class Layout(object):
         for edge in links:
             self._add_edge(edge[0], edge[1], False)
     # ==================================================================
-    def link_unidir(self, *links: Tuple[Port, Port]) -> None:
+    def add_unidir_link(self, port_1: Port, port_2: Port) -> None:
+        """Add one unidirectionnal edge in the Layout
+
+        Parameters
+        ----------
+        port_1 :
+            First port to be linked.
+        port_2 :
+            Second port to be linked.
+
+        """
+        self._add_edge(port_1, port_2, True)
+    # ==================================================================
+    def add_unidir_links(self, *links: Tuple[Port, Port]) -> None:
         """Add a series of unidirectionnal edges in the Layout
 
         Parameters
@@ -257,7 +283,20 @@ class Layout(object):
         for edge in links:
             self._add_edge(edge[0], edge[1], True)
     # ==================================================================
-    def del_link(self, *links: Tuple[Port, Port]) -> None:
+    def del_link(self, port_1: Port, port_2: Port) -> None:
+        """Delete a series of edges in the Layout.
+
+        Parameters
+        ----------
+        port_1 :
+            First port in the edge to be deleted.
+        port_2 :
+            Second port in the edge to be deleted.
+
+        """
+        self._del_edge(port_1, port_2)
+    # ==================================================================
+    def del_links(self, *links: Tuple[Port, Port]) -> None:
         """Delete a series of edges in the Layout.
 
         Parameters
