@@ -49,7 +49,7 @@ class AbsorptionSection(AbstractParameter):
                  medium: str = cst.DEF_FIBER_MEDIUM,
                  T: float = cst.TEMPERATURE,
                  sigma_e: Optional[Union[float, Callable]] = None) -> None:
-        """
+        r"""
         Parameters
         ----------
         dopant :
@@ -81,7 +81,7 @@ class AbsorptionSection(AbstractParameter):
     def __call__(self, omega: np.ndarray) -> np.ndarray: ...
     # ------------------------------------------------------------------
     def __call__(self, omega):
-        """Compute the derivatives of the absorption cross sections.
+        r"""Compute the derivatives of the absorption cross sections.
 
         Parameters
         ----------
@@ -295,5 +295,5 @@ if __name__ == "__main__":
 
     oc.plot2d(x_data, y_data, x_labels=['Lambda'],
               y_labels=[r'Absorption cross section, $\,\sigma_a\,(nm^2)$'],
-              split=True, plot_colors=['red'], plot_titles=plot_titles,
-              plot_linestyles=['-.'], opacity=[0.0])
+              split=True, line_colors=['red'], plot_titles=plot_titles,
+              line_styles=['-.'], line_opacities=[0.0])
