@@ -52,10 +52,10 @@ class ResonantIndex(AbstractParameter):
 
     References
     ----------
-    .. [11] Digonnet, M.J., Sadowski, R.W., Shaw, H.J. and Pantell, R.H.,
-           1997. Experimental evidence for strong UV transition
-           contribution in the resonant nonlinearity of doped fibers.
-           Journal of lightwave technology, 15(2), pp.299-303.
+    .. [11] Digonnet, M.J., Sadowski, R.W., Shaw, H.J. and Pantell,
+            R.H., 1997. Experimental evidence for strong UV transition
+            contribution in the resonant nonlinearity of doped fibers.
+            Journal of lightwave technology, 15(2), pp.299-303.
 
     """
 
@@ -67,9 +67,13 @@ class ResonantIndex(AbstractParameter):
         medium :
             The medium in which the wave propagates.
         n_0 :
-            The raw refratvie index of the medium.
+            The raw refratvie index of the medium.  If a
+            callable is provided, the variable must be angular
+            frequency. :math:`[ps^{-1}]`
         N :
             The population of the metastable level. :math:`[nm^{-3}]`
+            If a callable is provided, the variable must be angular
+            frequency. :math:`[ps^{-1}]`
 
         """
         self._medium: str = util.check_attr_value(medium.lower(), MEDIA,
@@ -107,7 +111,7 @@ class ResonantIndex(AbstractParameter):
     def __call__(self, omega: np.ndarray) -> np.ndarray: ...
     # ------------------------------------------------------------------
     def __call__(self, omega):
-        """Compute the resonant index.
+        r"""Compute the resonant index.
 
         Parameters
         ----------
@@ -342,4 +346,4 @@ if __name__ == "__main__":
 
     oc.plot2d([lambdas, lambdas], delta_n_data, x_labels=x_labels,
               y_labels=y_labels, plot_titles=plot_titles, split=True,
-              opacity=[0.0])
+              line_opacities=[0.0])
